==> chat_messenger-1.0.0.tar.gz: chat_messenger/src/Controller/ChatMessengerController.php <==
<?php

namespace Drupal\chat_messenger\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Database;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\user\Entity\User;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 *
 */
class ChatMessengerController extends ControllerBase {

  /**
   *
   */
  public function userList() {
    $current_user = \Drupal::currentUser();
    $users = $this->getAllUsers();
    $output = '<div class="chat-user-list"> Users List ';

    foreach ($users as $user) {
      if ($user->id() == $current_user->id() || $user->id() == 0) {
        continue;
      }

      $chat_url = Url::fromRoute('chat_messenger.message_list', ['user' => $user->id()]);

      $chat_link = Link::fromTextAndUrl(
        $this->t('Chat'),
        $chat_url
      )->toString();

      $output .=
      '<div class="chat-user-item">
                    <span class="chat-user-name">' . $user->getAccountName() . '</span>
                    <span class="chat-icon">' . $chat_link . '</span>
                  </div>';
    }

    $output .= '</div>';

    return [
      '#markup' => $output,
      '#attached' => [
        'library' => [
          'chat_messenger/chat_messenger_js',
          'chat_messenger/chat_messenger_styles',
        ],
      ],
    ];
  }

  /**
   * Get all users.
   */
  private function getAllUsers() {
    return \Drupal::entityTypeManager()->getStorage('user')->loadMultiple();
  }

  /**
   * Displays the chat interface for the selected user.
   */
  public function messageList($user) {
    $current_user = \Drupal::currentUser();

    if ($current_user->id() == $user) {
      return [
        '#markup' => $this->t('You cannot chat with yourself.'),
      ];
    }

    $messages = $this->getMessages($current_user->id(), $user);
    $output = '<div class="chat-message-list">';

    foreach ($messages as $message) {
      $message_class = ($message->from_uid == $current_user->id()) ? 'sent' : 'received';
      $output .=
        '<div class="message ' . $message_class . '" id="message-' . $message->id . '">
            <strong>' . $this->t('@from_uid:', ['@from_uid' => User::load($message->from_uid)->getAccountname()]) . '</strong>
            <p>' . $message->message . '</p>
            <small>' . date('Y-m-d H:i:s', $message->created) . '</small>
        </div>';
    }

    $output .= '</div>';

    $form = \Drupal::formBuilder()->getForm('Drupal\chat_messenger\Form\ChatMessageForm', $user);
    $form['#cache'] = ['max-age' => 0];

    return [
      '#markup' => $output,
      '#attached' => [
        'library' => [
          'chat_messenger/chat_messenger_js',
          'chat_messenger/chat_messenger_styles',
        ],
      ],
      'chat_message_form' => $form,
      '#cache' => [
        'max-age' => 0,
      ],
    ];
  }

  /**
   * Retrieves chat messages.
   */
  private function getMessages($from_uid, $to_uid) {
    $query = Database::getConnection()->select('chat_message', 'm');
    $query->fields('m');
    $query->condition('m.from_uid', $to_uid);
    $query->condition('m.to_uid', $from_uid);
    $query->orConditionGroup();
    $query->orderBy('m.created', 'ASC');
    return $query->execute()->fetchAll();
  }

  /**
   * Send a message via AJAX.
   */
  public function sendMessage(Request $request) {
    $message = $request->get('message');
    $recipient_id = $request->get('recipient_id');
    $sender_id = \Drupal::currentUser()->id();
    $created = \Drupal::time()->getRequestTime();

    // Insert chat into the database.
    $message_id = Database::getConnection()->insert('chat_message')
      ->fields([
        'from_uid' => $sender_id,
        'to_uid' => $recipient_id,
        'message' => $message,
        'created' => $created,
      ])
      ->execute();

    // Fetch the newly created message.
    $new_message = Database::getConnection()->select('chat_message', 'm')
      ->fields('m')
      ->condition('m.id', $message_id)
      ->execute()
      ->fetchObject();

    // Prepare the response with the newly sent message.
    $response = [
      'message' => $new_message->message,
      'from' => User::load($new_message->from_uid)->getAccountname(),
      'created' => date('Y-m-d H:i:s', $new_message->created),
      'message_id' => $new_message->id,
    ];

    $this->sendNotification($recipient_id, $new_message->message);
    $json_response = new JsonResponse($response);
    $json_response->setCache([
      'max-age' => 0,
    ]);

    return $json_response;
  }

  /**
   * Send a notification to the recipient.
   */
  private function sendNotification($recipient_id, $message) {
    \Drupal::messenger()->addMessage($this->t('You have a new message: %message', ['%message' => $message]), 'status');
  }

  /**
   * Retrieve new messages for real-time updates.
   */
  public function getNewMessages(Request $request) {
    $current_user = \Drupal::currentUser();
    $recipient_id = $request->get('recipient_id');

    $new_messages = $this->getMessages($current_user->id(), $recipient_id);

    $response = [];
    foreach ($new_messages as $message) {
      $response['new_messages'][] = [
        'message' => $message->message,
        'from' => User::load($message->from_uid)->getUsername(),
        'created' => date('Y-m-d H:i:s', $message->created),
      ];
    }

    return new JsonResponse($response);
  }

}

==> chat_messenger-1.0.1.tar.gz: chat_messenger/src/Controller/ChatMessengerController.php <==
<?php

namespace Drupal\chat_messenger\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Database;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\user\Entity\User;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 *
 */
class ChatMessengerController extends ControllerBase {

  /**
   *
   */
  public function userList() {
    $current_user = \Drupal::currentUser();
    $users = $this->getAllUsers();
    $output = '<div class="chat-user-list"> Users List ';

    foreach ($users as $user) {
      if ($user->id() == $current_user->id() || $user->id() == 0) {
        continue;
      }

      $chat_url = Url::fromRoute('chat_messenger.message_list', ['user' => $user->id()]);

      $chat_link = Link::fromTextAndUrl(
        $this->t('Chat'),
        $chat_url
      )->toString();

      $output .=
      '<div class="chat-user-item">
                    <span class="chat-user-name">' . $user->getAccountName() . '</span>
                    <span class="chat-icon">' . $chat_link . '</span>
                  </div>';
    }

    $output .= '</div>';

    return [
      '#markup' => $output,
      '#attached' => [
        'library' => [
          'chat_messenger/chat_messenger_js',
          'chat_messenger/chat_messenger_styles',
        ],
      ],
    ];
  }

  /**
   * Get all users.
   */
  private function getAllUsers() {
    return \Drupal::entityTypeManager()->getStorage('user')->loadMultiple();
  }

  /**
   *
   */
  private function getSentMessages($from_uid, $to_uid) {

    $query = Database::getConnection()->select('chat_message', 'm');
    $query->fields('m');

    $query->condition('m.from_uid', $from_uid)
      ->condition('m.to_uid', $to_uid);

    $query->orderBy('m.created', 'ASC');

    return $query->execute()->fetchAll();
  }

  /**
   *
   */
  private function getReceivedMessages($from_uid, $to_uid) {

    $query = Database::getConnection()->select('chat_message', 'm');
    $query->fields('m');

    $query->condition('m.from_uid', $to_uid)
      ->condition('m.to_uid', $from_uid);

    $query->orderBy('m.created', 'ASC');

    return $query->execute()->fetchAll();
  }

  /**
   *
   */
  public function messageList($user) {
    $current_user = \Drupal::currentUser();

    if ($current_user->id() == $user) {
      return [
        '#markup' => $this->t('You cannot chat with yourself.'),
      ];
    }

    $sent_messages = $this->getSentMessages($current_user->id(), $user);
    $received_messages = $this->getReceivedMessages($current_user->id(), $user);

    $messages = array_merge($sent_messages, $received_messages);

    usort($messages, function ($a, $b) {
      return $a->created - $b->created;
    });

    $output = '<div class="chat-message-list">';

    foreach ($messages as $message) {
      $message_class = ($message->from_uid == $current_user->id()) ? 'sent' : 'received';

      $formatted_date = date('Y-m-d H:i:s', $message->created);

      $output .=
          '<div class="message ' . $message_class . '" id="message-' . $message->id . '">
              <strong>' . $this->t('@from_uid:', ['@from_uid' => User::load($message->from_uid)->getAccountname()]) . '</strong>
              <p>' . nl2br($message->message) . '</p> <!-- Preserve newlines -->
              <small>' . $formatted_date . '</small>
          </div>';
    }

    $output .= '</div>';

    $form = \Drupal::formBuilder()->getForm('Drupal\chat_messenger\Form\ChatMessageForm', $user);
    $form['#cache'] = ['max-age' => 0];

    return [
      '#markup' => $output,
      '#attached' => [
        'library' => [
          'chat_messenger/chat_messenger_js',
          'chat_messenger/chat_messenger_styles',
        ],
      ],
      'chat_message_form' => $form,
      '#cache' => [
        'max-age' => 0,
      ],
    ];
  }

  /**
   * Send a message via AJAX.
   */
  public function sendMessage(Request $request) {
    $message = $request->get('message');
    $recipient_id = $request->get('recipient_id');
    $sender_id = \Drupal::currentUser()->id();
    $created = \Drupal::time()->getRequestTime();

    // Insert chat into the database.
    $message_id = Database::getConnection()->insert('chat_message')
      ->fields([
        'from_uid' => $sender_id,
        'to_uid' => $recipient_id,
        'message' => $message,
        'created' => $created,
      ])
      ->execute();

    // Fetch the newly created message.
    $new_message = Database::getConnection()->select('chat_message', 'm')
      ->fields('m')
      ->condition('m.id', $message_id)
      ->execute()
      ->fetchObject();

    // Prepare the response with the newly sent message.
    $response = [
      'message' => $new_message->message,
      'from' => User::load($new_message->from_uid)->getAccountname(),
      'created' => date('Y-m-d H:i:s', $new_message->created),
      'message_id' => $new_message->id,
    ];

    $this->sendNotification($recipient_id, $new_message->message);
    $json_response = new JsonResponse($response);
    $json_response->setCache([
      'max-age' => 0,
    ]);

    return $json_response;
  }

  /**
   * Send a notification to the recipient.
   */
  private function sendNotification($recipient_id, $message) {
    \Drupal::messenger()->addMessage($this->t('You have a new message: %message', ['%message' => $message]), 'status');
  }

  /**
   * Retrieve new messages for real-time updates.
   */
  public function getNewMessages(Request $request) {
    $current_user = \Drupal::currentUser();
    $recipient_id = $request->get('recipient_id');

    $new_messages = $this->getMessages($current_user->id(), $recipient_id);

    $response = [];
    foreach ($new_messages as $message) {
      $response['new_messages'][] = [
        'message' => $message->message,
        'from' => User::load($message->from_uid)->getUsername(),
        'created' => date('Y-m-d H:i:s', $message->created),
      ];
    }

    return new JsonResponse($response);
  }

}
